slepc-3.18.0 2022-10-01
Report Typos and Errors

# LMEConvergedReasonView

Displays the reason an LME solve converged or diverged.

### Synopsis

    #include "slepclme.h"
    PetscErrorCode LMEConvergedReasonView(LME lme,PetscViewer viewer)

Collective on lme

### Input Parameters

| lme | - the linear matrix equation context
| viewer | - the viewer to display the reason

### Options Database Keys

| -lme_converged_reason | - print reason for convergence, and number of iterations

### Note

To change the format of the output call PetscViewerPushFormat(viewer,format) before this call. Use PETSC_VIEWER_DEFAULT for the default, use PETSC_VIEWER_FAILED to only display a reason if it fails. The latter can be set in the command line with -lme_converged_reason ::failed

### See Also

LMESetTolerances(), LMEGetIterationNumber(), LMEConvergedReasonViewFromOptions()

### Level

intermediate

### Location

src/lme/interface/lmebasic.c
Index of all LME routines
Table of Contents for all manual pages
Index of all manual pages